pub struct MessageInteractionMetadata {
pub id: Snowflake,
pub interaction_type: Option<InteractionType>,
pub user: User,
pub authorizing_integration_owners: IntegrationOwners,
pub original_response_message_id: Option<Snowflake>,
pub target_user: Option<User>,
pub target_message_id: Option<Snowflake>,
pub interacted_message_id: Option<Snowflake>,
pub triggering_interaction_metadata: Option<Box<MessageInteractionMetadata>>,
}Expand description
Discord Message Interaction Metadata Object
Fields
id: SnowflakeId of the interaction
interaction_type: Option<InteractionType>The type of interaction
user: UserUser who triggered the interaction
IDs for installation context(s) related to an interaction. Details in Authorizing Integration Owners Object
original_response_message_id: Option<Snowflake>ID of the original response message, present only on follow-up messages
target_user: Option<User>The user the command was run on, present only on user command interactions
target_message_id: Option<Snowflake>The ID of the message the command was run on, present only on message command interactions. The original response message will also have message_reference and referenced_message pointing to this message.
interacted_message_id: Option<Snowflake>ID of the message that contained interactive component, present only on messages created from component interactions
triggering_interaction_metadata: Option<Box<MessageInteractionMetadata>>Metadata for the interaction that was used to open the modal, present only on modal submit interactions