pub struct ApplicationCommandOption {Show 14 fields
pub option_type: InteractionOptionType,
pub name: String,
pub name_localizations: Option<HashMap<String, String>>,
pub description: String,
pub description_localizations: Option<HashMap<String, String>>,
pub required: Option<bool>,
pub choices: Option<Vec<ApplicationCommandOptionChoice>>,
pub options: Option<Vec<ApplicationCommandOption>>,
pub channel_types: Option<Vec<ChannelType>>,
pub min_value: Option<f64>,
pub max_value: Option<f64>,
pub min_length: Option<i64>,
pub max_length: Option<i64>,
pub autocomplete: Option<bool>,
}Expand description
Discord Application Command Option Object
Fields
option_type: InteractionOptionTypeType of option
name: String1-32 character name
name_localizations: Option<HashMap<String, String>>Localization dictionary for the name field. Values follow the same restrictions as name
description: String1-100 character description
description_localizations: Option<HashMap<String, String>>Localization dictionary for the description field. Values follow the same restrictions as description
required: Option<bool>If the parameter is required or optional–default false
choices: Option<Vec<ApplicationCommandOptionChoice>>Choices for STRING, INTEGER, and NUMBER types for the user to pick from, max 25
options: Option<Vec<ApplicationCommandOption>>If the option is a subcommand or subcommand group type, these nested options will be the parameters
channel_types: Option<Vec<ChannelType>>If the option is a channel type, the channels shown will be restricted to these types
min_value: Option<f64>If the option is an INTEGER or NUMBER type, the minimum value permitted
max_value: Option<f64>If the option is an INTEGER or NUMBER type, the maximum value permitted
min_length: Option<i64>For option type STRING, the minimum allowed length (minimum of 0, maximum of 6000)
max_length: Option<i64>For option type STRING, the maximum allowed length (minimum of 1, maximum of 6000)
autocomplete: Option<bool>If autocomplete interactions are enabled for this STRING, INTEGER, or NUMBER type option